@@ -1,4 +1,4 @@
-//! Cradle's `prelude` module.
+//! `cradle`'s `prelude` module.
 //! It re-exports the most commonly used items from cradle.
 //! We recommend importing cradle like this:
 //! `use cradle::prelude::*;`
@@ -7,8 +7,8 @@
 //! see the documentation in the [crate root](crate).
 
 pub use crate::{
-    cmd, cmd_result, cmd_unit,
     error::Error,
     input::{CurrentDir, Env, Input, LogCommand, Split, Stdin},
     output::{Output, Status, Stderr, StdoutTrimmed, StdoutUntrimmed},
+    run, run_output, run_result,
 };
